#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-auth
version: 1.4.13.2
id: yesod-auth-1.4.13.2-e638e081132a85618f37f43080bc4eb4
key: yesod_1AbRBQZZLwxL7hUDre699C
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Authentication for Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-auth>
category: Web, Yesod
author: Michael Snoyman, Patrick Brisbin
exposed: True
exposed-modules:
    Yesod.Auth Yesod.Auth.BrowserId Yesod.Auth.Dummy Yesod.Auth.Email
    Yesod.Auth.OpenId Yesod.Auth.Rpxnow Yesod.Auth.Message
    Yesod.Auth.GoogleEmail Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded
hidden-modules: Yesod.Auth.Routes Yesod.PasswordStore
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.13.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.13.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-auth-1.4.13.2
hs-libraries: HSyesod-auth-1.4.13.2-1AbRBQZZLwxL7hUDre699C
depends:
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    authenticate-1.3.3.1-d5d29d33a55e5a55915307e270a92892
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
    conduit-extra-1.1.13.1-eddf025ec4463f8bba96cb21182c4b0f
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptohash-0.11.9-1ce6a3e7b661f39b36d188b8c49a9b44
    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
    email-validate-2.2.0-b56e57eb2689ad2a5bb9495f35baa8f4
    file-embed-0.0.10-c7da10dfba0f55c7c135317c0bfb8508
    http-client-0.4.28-bc84c1de0ba23b26cbd36cc941948a7e
    http-conduit-2.1.10.1-25cf7e0ab425a3f9a6e4adec2d684722
    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
    mime-mail-0.4.11-d9015aaaa236b99cae24cbb7fe985a3e
    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
    nonce-1.0.2-4d1212dfb084a803f723eea311d0a719
    persistent-2.2.4.1-d8d907c8c62628a6667ab3fa39fc892f
    persistent-template-2.1.6-83163c252d18f4a1e745e383b4fcf281
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
    safe-0.3.9-b613242f536083d5bb04920ede356aea
    shakespeare-2.0.8.2-ff3f7104513a25f68869f5890fce9d82
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
    yesod-core-1.4.20.2-aced7b6b1008af0f1a8e5e3876fc55af
    yesod-form-1.4.7.1-5d1acfd5ba57bcb9acd30a4f556f6cdd
    yesod-persistent-1.4.0.5-a3f7b6a3b9261de48209b70a4cc548df
haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
haddock-html: /usr/share/doc/haskell-yesod-auth/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
